pub struct Sha256Example { /* private fields */ }Trait Implementations
Sourceimpl ExampleCircuit for Sha256Example
impl ExampleCircuit for Sha256Example
Sourcetype Params = HasherParams
type Params = HasherParams
Circuit parameters that affect the structure of the circuit.
These are typically compile-time constants or bounds.
Sourcetype Instance = HasherInstance
type Instance = HasherInstance
Instance data used to populate the witness.
This represents the actual input values for a specific proof.
Sourcefn build(params: HasherParams, builder: &mut CircuitBuilder) -> Result<Self>
fn build(params: HasherParams, builder: &mut CircuitBuilder) -> Result<Self>
Build the circuit with the given parameters. Read more
Sourcefn populate_witness(
&self,
instance: HasherInstance,
w: &mut WitnessFiller<'_>,
) -> Result<()>
fn populate_witness( &self, instance: HasherInstance, w: &mut WitnessFiller<'_>, ) -> Result<()>
Populate witness values for a specific instance. Read more